@@ -8,9 +8,8 @@
 #' @return an object of class \code{DropDownMenu}.
 #' @export
 #' @examples
-#' #START_TAG_TEST
+#' #
 #' @example examples/DropDownMenu.R
-#' @example examples/STOP_TAG_TEST.R
 #' @seealso \code{\link{bsdoc}}, \code{\link{addLinkItem}}, \code{\link{addBootstrapMenu}}
 DropDownMenu = function( label ) {
 	out = list()
@@ -18,3 +17,8 @@ DropDownMenu = function( label ) {
 	class( out ) = "DropDownMenu"
 	out
 }
+#' @export
+print.DropDownMenu = function(x, ...){
+	cat("DropDownMenu object")
+	invisible()
+}
