@@ -29,14 +29,12 @@
 #' @example examples/STOP_TAG_TEST.R
 #' @seealso \code{\link{bsdoc}}, \code{\link{addMarkdown.bsdoc}}, 
 #' \code{\link{pot}}
-#' @method addParagraph bsdoc
-#' @S3method addParagraph bsdoc
+#' @export
 addParagraph.bsdoc = function(doc, value, 
 		par.properties = parProperties(), 
 		restart.numbering = FALSE, ... ) {
 
 	if( inherits( value, "character" ) ){
-		value = gsub("(\\n|\\r)", "", value )
 		x = lapply( value, function(x) pot(value = x) )
 		value = do.call( "set_of_paragraphs", x )
 	}
