@@ -1,11 +1,18 @@
 class.html4r.RAPHAELGraphics = "org/lysis/reporters/html4r/elements/RAPHAELGraphics"
 class.html4r.Title = "org/lysis/reporters/html4r/elements/Title"
-class.pptx4r.SlideLayout = "org/lysis/reporters/pptx4r/elements/layouts/SlideLayout"
+class.pptx4r.LayoutDescription = "org/lysis/reporters/pptx4r/elements/template/LayoutDescription"
+class.pptx4r.SlidePart = "org/docx4j/openpackaging/parts/PresentationML/SlidePart"
 
 # FlexTable
 class.FlexTable = "org/lysis/reporters/tables/FlexTable"
 class.FlexRow = "org/lysis/reporters/tables/FlexRow"
 class.FlexCell = "org/lysis/reporters/tables/FlexCell"
+class.MetaRows = "org/lysis/reporters/tables/MetaRows"
+
+# Lists
+class.NumberingDefinition = "org.lysis.reporters.lists.NumberingDefinition"
+class.ListDefinition = "org.lysis.reporters.lists.ListDefinition"
+
 
 # format properties
 class.tables.BorderProperties = "org/lysis/reporters/formats/BorderProperties"
@@ -15,8 +22,7 @@ class.text.TextProperties = "org/lysis/reporters/formats/TextProperties"
 
 # document objects
 class.docx4r.document = "org/lysis/reporters/docs/docx4R"
-class.html4r.document = "org/lysis/reporters/docs/html4R"
-class.html4r.HTMLPageContent = "org/lysis/reporters/docs/HTMLPageContent"
+class.BootstrapPage.document = "org/lysis/reporters/docs/BootstrapPage"
 class.pptx4r.document = "org/lysis/reporters/docs/pptx4R"
 class.pptx4r.SlideContent = "org/lysis/reporters/docs/SlideContent"
 
@@ -24,9 +30,16 @@ class.pptx4r.SlideContent = "org/lysis/reporters/docs/SlideContent"
 class.Image = "org/lysis/reporters/img/Image"
 class.Paragraph = "org/lysis/reporters/text/Paragraph"
 class.ParagraphSet = "org/lysis/reporters/text/ParagraphSet"
+class.Footnote = "org/lysis/reporters/text/FootNote"
 class.TOC = "org/lysis/reporters/text/TOC"
 class.DrawingML = "org/lysis/reporters/img/DrawingML"
 class.RScript = "org/lysis/reporters/text/RScript"
+class.BootstrapMenu = "org/lysis/reporters/html4r/elements/menu/BootstrapMenu"
+class.DropDown = "org/lysis/reporters/html4r/elements/menu/Dropdown"
+class.MenuLink = "org/lysis/reporters/html4r/elements/menu/MenuLink"
+class.Separator = "org/lysis/reporters/html4r/elements/menu/Separator"
+class.Iframe = "org/lysis/reporters/html4r/elements/Iframe"
+
 # fonts
 class.fontMetric = "org/lysis/reporters/graphicaldevices/fonts/FontMetric"
 class.fontInfo = "org/lysis/reporters/graphicaldevices/fonts/FontInfo"
