@@ -2,10 +2,6 @@
  * This file is part of ReporteRs.
  * Copyright (c) 2014, David Gohel All rights reserved.
  *
- * It is inspired from sources of R package grDevices:
- * Copyright (C) 1995, 1996  Robert Gentleman and Ross Ihaka
- * Copyright (C) 1998--2014  The R Core Team
- *
  * ReporteRs is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation, either version 3 of the License, or
@@ -55,7 +51,8 @@ typedef struct {
 	double offy;
 	double extx;
 	double exty;
-	
+    double clippedx0, clippedy0, clippedx1, clippedy1;
+
 	double* x;
 	double* y;
 	double* width;
